@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.87';
+our $VERSION = '0.88';
 
 use Dist::Zilla 6.0;
 
@@ -42,7 +42,6 @@ use Dist::Zilla::Plugin::MetaConfig;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::MetaProvides::Package;
 use Dist::Zilla::Plugin::MetaResources;
-use Dist::Zilla::Plugin::MinimumPerl;
 use Dist::Zilla::Plugin::MojibakeTests;
 use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::PPPort;
@@ -276,7 +275,6 @@ sub _build_plugins {
         $self->make_tool,
         $self->_gather_dir_plugin,
         $self->_basic_plugins,
-        'MinimumPerl',
         $self->_authority_plugin,
         $self->_auto_prereqs_plugin,
         $self->_copy_files_from_build_plugin,
@@ -826,7 +824,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.87
+version 0.88
 
 =head1 SYNOPSIS
 
